polywrap_client_default_config 0.1.11

Default configuration for Polywrap Client
docs.rs failed to build polywrap_client_default_config-0.1.11
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: polywrap_client_default_config-0.1.8-beta.2